@@ -1,5 +1,6 @@
 # from PyThat import MeasurementTree
 from h5to_nc import MeasurementTree
+import h5to_nc
 import xarray as xr
 import matplotlib.pyplot as plt
 
@@ -41,13 +42,18 @@ path = r"C:\Users\Matthias\Desktop\floquet_bls_angle_rotation_3.h5"
 #     plt.show()
 
 
-data = MeasurementTree(path, index=True, override=True)
+data = MeasurementTree(path, index=True, override=False)
+d = data.dataset
+print('Here1!')
+print(d)
+d = h5to_nc.consolidate_dims(d, 'Frequency', "Frequency")
+d = h5to_nc.consolidate_dims(d, 'Frequency', "Frequency_1")
+print('Here2!')
+print(d)
 # print(data.tree_string)
 # print(data.definition)
 # print(data.labbook)
 # print(data.logs)
-print(data.dataset)
-
 for i in data.dataset.values():
     for j in i.coords.values():
         print(f"Name: {j.name}, Units: {j.attrs['units']}")
